#!/bin/sh
# mk86asm.sh, make an assembly program for the TI-86 calculator
# Copyright 2003, 2004 Chris Williams <cow3.14@juno.com>
# 
# make sure each of the programs used in here are in your PATH env variable.

programname="`basename $0`"

function usage {
	(
	echo "Usage: $programname [-n varname] file ..."
	echo "  where file is an assembly-language file"
	echo "Options:"
	echo "  -h           Show this help and exit"
	echo "  -n varname   Set the on-calc variable name to varname. This"
	echo "               applies only to the next file."
	) >&2
}

if [ $# -eq 0 ]; then usage; exit 1; fi

varname=""
getvarname=false
anyfiles=false

for f; do
	if $getvarname; then varname="$f"; getvarname=false; continue; fi
	case "$f" in
	-h)
		usage
		exit ;;
	-n)
		getvarname=true
		continue ;;
	-n=*)
		varname="`(echo "$f" | cut -b 4-)`"
		continue ;;
	esac
	anyfiles=true
	
	# chop off the extension (from the last dot to the end)
	base=`echo $f | awk -v FS=. -v OFS=. '{NF=NF-1; print $0}'`
	if [ ! "$base" ]; then base="$f"; fi
	
	if [ "$f" = "$base.hex" -o "$f" = "$base.lst" ]; then
		echo "$programname: input file cannot have .hex or .lst suffix" >&2
		continue
	fi
	
	#echo "tpasm -P z80 -o intel $base.hex -l $base.lst $f"
	if ! tpasm -P z80 -o intel "$base.hex" -l "$base.lst" "$f" ; then
		echo "$programname: assembly failed on $f" >&2
		continue
	fi
	
	if ! (head -1 "$base.hex" | grep '^:..D748' >/dev/null); then
		echo "$programname: warning: $f does not start at _asm_exec_ram (0xD748)" >&2
	fi
	
	if [ ! -n "$varname" ]; then varname="$base"; fi
	
	# should the variable file have the name of the variable
	# or of the source file (in the case where varname is supplied)?
	if (ihxtobin < "$base.hex" | mk86p -k -n "$varname" - "$varname.86p" \
	 -c "TI-86 asm program store in prgm variable. "); then
		echo "***$varname.86p made successfully***"
	fi
	varname=""
done

if ! $anyfiles; then usage; exit 1; fi
